[![Support][support]][support-url]
[![Donation](https://img.shields.io/badge/donation-PayPal-brightgreen)](https://paypal.me/MayanEDMS)
[![docker_version][docker_version]][docker_url]
[![pypi][pypi]][pypi-url]
[![Docker pulls](https://img.shields.io/docker/pulls/mayanedms/mayanedms.svg)](https://hub.docker.com/r/mayanedms/mayanedms/)
[![Docker Stars](https://img.shields.io/docker/stars/mayanedms/mayanedms.svg)](https://hub.docker.com/r/mayanedms/mayanedms/)
![license][license]

[docker_version]: https://img.shields.io/docker/v/mayanedms/mayanedms?label=Docker
[docker_url]: https://hub.docker.com/r/mayanedms/mayanedms

[pypi]: https://img.shields.io/pypi/v/mayan-edms.svg
[pypi-url]: https://pypi.org/project/mayan-edms/

[builds]: https://gitlab.com/mayan-edms/mayan-edms/badges/master/build.svg
[builds-url]: https://gitlab.com/mayan-edms/mayan-edms/pipelines

[license]: https://img.shields.io/pypi/l/mayan-edms.svg?style=flat
[license-url]: https://gitlab.com/mayan-edms/mayan-edms/blob/master/LICENSE

[support]: https://img.shields.io/badge/Get_support-brightgreen
[support-url]: https://www.mayan-edms.com/support/

<div align="center">
  <a href="http://www.mayan-edms.com">
    <img width="200" height="200" src="https://gitlab.com/mayan-edms/mayan-edms/raw/master/docs/_static/mayan_logo.png">
  </a>
  <br>
  <br>
  <p>
    The most advanced open source document management system.
  <p>

<p align="center">
    <img width="400" src="https://gitlab.com/mayan-edms/mayan-edms/raw/master/docs/_static/overview.gif">
</p>

It is very easy to get started with Mayan EDMS, just deploy the official
Docker Compose file.

    curl https://gitlab.com/mayan-edms/mayan-edms/-/raw/master/docker/docker-compose.yml -O
    curl https://gitlab.com/mayan-edms/mayan-edms/-/raw/master/docker/.env -O
    docker compose up --detach

The complete documentation is available at: https://docs.mayan-edms.com/parts/installation.html

For more in-depth articles, tutorials, and troubleshooting available in the Knowledge Base.

<p align="center">
    <a href="https://forum.mayan-edms.com/s/prod_Ogq3lYaoROC02Q">
        <img width="400" src="https://docs.mayan-edms.com/_static/knowledge-base.jpg">
    </a>
</p>

Click the image or visit: https://forum.mayan-edms.com/s/prod_Ogq3lYaoROC02Q

<h2 align="center">Important links</h2>


- [Homepage](http://www.mayan-edms.com)
- [Documentation](https://docs.mayan-edms.com)
- [Contributing](https://gitlab.com/mayan-edms/mayan-edms/blob/master/CONTRIBUTING.md)
- [Forum](https://forum.mayan-edms.com/)
- [Source code, issues, bugs](https://gitlab.com/mayan-edms/mayan-edms)
- [Plug-ins, other related projects](https://gitlab.com/mayan-edms/)
- [Translations](https://www.transifex.com/rosarior/mayan-edms/)
- [Videos](https://www.youtube.com/channel/UCJOOXHP1MJ9lVA7d8ZTlHPw)

